==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/medialive/kotlin/outputs/ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettings.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.medialive.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 *
 * @property h265PackagingType
 * @property hlsSettings
 * @property nameModifier String concatenated to the end of the destination filename. Required for multiple outputs of the same type.
 * @property segmentModifier
 */
public data class ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettings(
    public val h265PackagingType: String? = null,
    public val hlsSettings:
    ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettings,
    public val nameModifier: String? = null,
    public val segmentModifier: String? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.medialive.outputs.ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettings):
            ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettings =
            ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettings(
                h265PackagingType = javaType.h265PackagingType().map({ args0 -> args0 }).orElse(null),
                hlsSettings = javaType.hlsSettings().let({ args0 ->
                    com.pulumi.aws.medialive.kotlin.outputs.ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettings.Companion.toKotlin(args0)
                }),
                nameModifier = javaType.nameModifier().map({ args0 -> args0 }).orElse(null),
                segmentModifier = javaType.segmentModifier().map({ args0 -> args0 }).orElse(null),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/medialive/kotlin/outputs/ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettings.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.medialive.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 *
 * @property h265PackagingType
 * @property hlsSettings
 * @property nameModifier String concatenated to the end of the destination filename. Required for multiple outputs of the same type.
 * @property segmentModifier
 */
public data class ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettings(
    public val h265PackagingType: String? = null,
    public val hlsSettings: ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettings,
    public val nameModifier: String? = null,
    public val segmentModifier: String? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.medialive.outputs.ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettings): ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettings =
            ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettings(
                h265PackagingType = javaType.h265PackagingType().map({ args0 -> args0 }).orElse(null),
                hlsSettings = javaType.hlsSettings().let({ args0 ->
                    com.pulumi.aws.medialive.kotlin.outputs.ChannelEncoderSettingsOutputGroupOutputOutputSettingsHlsOutputSettingsHlsSettings.Companion.toKotlin(args0)
                }),
                nameModifier = javaType.nameModifier().map({ args0 -> args0 }).orElse(null),
                segmentModifier = javaType.segmentModifier().map({ args0 -> args0 }).orElse(null),
            )
    }
}
